@@ -4,7 +4,8 @@ package MOP::Class;
 use strict;
 use warnings;
 
-use mro ();
+use mro  ();
+use Carp ();
 
 use UNIVERSAL::Object;
 
@@ -14,7 +15,7 @@ use MOP::Slot;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA;  BEGIN { @ISA  = 'UNIVERSAL::Object' };
@@ -40,7 +41,7 @@ sub superclasses {
 
 sub set_superclasses {
     my ($self, @superclasses) = @_;
-    die '[ARGS] You must specify at least one superclass'
+    Carp::croak('[ARGS] You must specify at least one superclass')
         if scalar( @superclasses ) == 0;
     MOP::Internal::Util::SET_GLOB_SLOT( $self->stash, 'ISA', \@superclasses );
     return;
@@ -63,7 +64,7 @@ MOP::Class - A representation of a class
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
