@@ -5,11 +5,12 @@ use strict;
 use warnings;
 
 use B            (); # nasty stuff, all nasty stuff
+use Carp         (); # errors and stuff
 use Sub::Name    (); # handling some sub stuff
 use Symbol       (); # creating the occasional symbol
 use Scalar::Util (); # I think I use blessed somewhere in here ...
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 ## ------------------------------------------------------------------
@@ -23,7 +24,7 @@ sub IS_VALID_MODULE_NAME {
 
 sub IS_STASH_REF {
     my ($stash) = @_;
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
     if ( my $name = B::svref_2object( $stash )->NAME ) {
         return IS_VALID_MODULE_NAME( $name );
@@ -33,28 +34,28 @@ sub IS_STASH_REF {
 
 sub GET_NAME {
     my ($stash) = @_;
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
     B::svref_2object( $stash )->NAME
 }
 
 sub GET_STASH_NAME {
     my ($stash) = @_;
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
     B::svref_2object( $stash )->STASH->NAME
 }
 
 sub GET_GLOB_NAME {
     my ($stash) = @_;
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
     B::svref_2object( $stash )->GV->NAME
 }
 
 sub GET_GLOB_STASH_NAME {
     my ($stash) = @_;
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
     B::svref_2object( $stash )->GV->STASH->NAME
 }
@@ -62,11 +63,11 @@ sub GET_GLOB_STASH_NAME {
 sub GET_GLOB_SLOT {
     my ($stash, $name, $slot) = @_;
 
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
-    die '[ARGS] You must specify a name'
+    Carp::croak('[ARGS] You must specify a name')
         unless defined $name;
-    die '[ARGS] You must specify a slot'
+    Carp::croak('[ARGS] You must specify a slot')
         unless defined $slot;
 
     # do my best to not autovivify, and
@@ -89,11 +90,11 @@ sub GET_GLOB_SLOT {
 sub SET_GLOB_SLOT {
     my ($stash, $name, $value_ref) = @_;
 
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless defined $stash;
-    die '[ARGS] You must specify a name'
+    Carp::croak('[ARGS] You must specify a name')
         unless defined $name;
-    die '[ARGS] You must specify a value REF'
+    Carp::croak('[ARGS] You must specify a value REF')
         unless defined $value_ref;
 
     {
@@ -115,7 +116,7 @@ sub SET_GLOB_SLOT {
 
 sub IS_CV_NULL {
     my ($cv) = @_;
-    die '[ARGS] You must specify a CODE reference'
+    Carp::croak('[ARGS] You must specify a CODE reference')
         unless $cv;
     my $op = B::svref_2object( $cv );
     return !! $op->isa('B::CV') && $op->ROOT->isa('B::NULL');
@@ -123,7 +124,7 @@ sub IS_CV_NULL {
 
 sub DOES_GLOB_HAVE_NULL_CV {
     my ($glob) = @_;
-    die '[ARGS] You must specify a GLOB'
+    Carp::croak('[ARGS] You must specify a GLOB')
         unless $glob;
     # NOTE:
     # If the glob eq -1 that means it may well be a null sub
@@ -145,26 +146,26 @@ sub DOES_GLOB_HAVE_NULL_CV {
 
 sub CREATE_NULL_CV {
     my ($in_pkg, $name) = @_;
-    die '[ARGS] You must specify a package name'
+    Carp::croak('[ARGS] You must specify a package name')
         unless defined $in_pkg;
-    die '[ARGS] You must specify a name'
+    Carp::croak('[ARGS] You must specify a name')
         unless defined $name;
     # this just tries to eval the NULL CV into
     # place, it is ugly, but works for now
-    eval "sub ${in_pkg}::${name}; 1;" or do { die $@ };
+    eval "sub ${in_pkg}::${name}; 1;" or do { Carp::croak($@) };
     return;
 }
 
 sub INSTALL_CV {
     my ($in_pkg, $name, $code, %opts) = @_;
 
-    die '[ARGS] You must specify a package name'
+    Carp::croak('[ARGS] You must specify a package name')
         unless defined $in_pkg;
-    die '[ARGS] You must specify a name'
+    Carp::croak('[ARGS] You must specify a name')
         unless defined $name;
-    die '[ARGS] You must specify a CODE reference'
+    Carp::croak('[ARGS] You must specify a CODE reference')
         unless $code && ref $code eq 'CODE';
-    die "[ARGS] You must specify a boolean value for `set_subname` option"
+    Carp::croak("[ARGS] You must specify a boolean value for `set_subname` option")
         if not exists $opts{set_subname};
 
     {
@@ -180,9 +181,9 @@ sub INSTALL_CV {
 sub REMOVE_CV_FROM_GLOB {
     my ($stash, $name) = @_;
 
-    die '[ARGS] You must specify a stash'
+    Carp::croak('[ARGS] You must specify a stash')
         unless $stash && ref $stash eq 'HASH';
-    die '[ARGS] You must specify a name'
+    Carp::croak('[ARGS] You must specify a name')
         unless defined $name;
 
     # find the glob we are looking for
@@ -227,15 +228,15 @@ sub REMOVE_CV_FROM_GLOB {
 sub APPLY_ROLES {
     my ($meta, $roles, %opts) = @_;
 
-    die '[ARGS] You must specify a metaclass to apply roles to'
+    Carp::croak('[ARGS] You must specify a metaclass to apply roles to')
         unless Scalar::Util::blessed( $meta );
-    die '[ARGS] You must specify a least one roles to apply as an ARRAY ref'
+    Carp::croak('[ARGS] You must specify a least one roles to apply as an ARRAY ref')
         unless $roles && ref $roles eq 'ARRAY' && scalar( @$roles ) != 0;
-    die "[ARGS] You must specify what type of object you want roles applied `to`"
+    Carp::croak("[ARGS] You must specify what type of object you want roles applied `to`")
         unless exists $opts{to};
 
     foreach my $r ( $meta->roles ) {
-        die "[ERROR] Could not find role ($_) in the set of roles in $meta (" . $meta->name . ")"
+        Carp::croak("[ERROR] Could not find role ($_) in the set of roles in $meta (" . $meta->name . ")")
             unless scalar grep { $r eq $_ } @$roles;
     }
 
@@ -246,12 +247,12 @@ sub APPLY_ROLES {
         $slot_conflicts
     ) = COMPOSE_ALL_ROLE_SLOTS( @meta_roles );
 
-    die "[CONFLICT] There should be no conflicting slots when composing (" . (join ', ' => @$roles) . ") into (" . $meta->name . ")"
+    Carp::croak("[CONFLICT] There should be no conflicting slots when composing (" . (join ', ' => @$roles) . ") into (" . $meta->name . ")")
         if scalar keys %$slot_conflicts;
 
     foreach my $name ( keys %$slots ) {
         # if we have a slot already by that name ...
-        die "[CONFLICT] Role Conflict, cannot compose slot ($name) into (" . $meta->name . ") because ($name) already exists"
+        Carp::croak("[CONFLICT] Role Conflict, cannot compose slot ($name) into (" . $meta->name . ") because ($name) already exists")
             if $meta->has_slot( $name );
         # otherwise alias it ...
         $meta->alias_slot( $name, $slots->{ $name } );
@@ -263,7 +264,7 @@ sub APPLY_ROLES {
         $required_methods
     ) = COMPOSE_ALL_ROLE_METHODS( @meta_roles );
 
-    die "[CONFLICT] There should be no conflicting methods when composing (" . (join ', ' => @$roles) . ") into the class (" . $meta->name . ") but instead we found (" . (join ', ' => keys %$method_conflicts)  . ")"
+    Carp::croak("[CONFLICT] There should be no conflicting methods when composing (" . (join ', ' => @$roles) . ") into the class (" . $meta->name . ") but instead we found (" . (join ', ' => keys %$method_conflicts)  . ")")
         if $opts{to} eq 'class'           # if we are composing into a class ...
         && (scalar keys %$method_conflicts) # and we have any conflicts ...
         # and the conflicts are not satisfied by the composing class ...
@@ -277,7 +278,7 @@ sub APPLY_ROLES {
             if $meta->name->can( $name );
     }
 
-    die "[CONFLICT] There should be no required methods when composing (" . (join ', ' => @$roles) . ") into (" . $meta->name . ") but instead we found (" . (join ', ' => keys %$required_methods)  . ")"
+    Carp::croak("[CONFLICT] There should be no required methods when composing (" . (join ', ' => @$roles) . ") into (" . $meta->name . ") but instead we found (" . (join ', ' => keys %$required_methods)  . ")")
         if $opts{to} eq 'class'            # if we are composing into a class ...
         && scalar keys %$required_methods; # and we have required methods ...
 
@@ -300,7 +301,7 @@ sub APPLY_ROLES {
 sub COMPOSE_ALL_ROLE_SLOTS {
     my @roles = @_;
 
-    die '[ARGS] You must specify a least one role to compose slots in'
+    Carp::croak('[ARGS] You must specify a least one role to compose slots in')
         if scalar( @roles ) == 0;
 
     my (%slots, %conflicts);
@@ -337,7 +338,7 @@ sub COMPOSE_ALL_ROLE_SLOTS {
 sub COMPOSE_ALL_ROLE_METHODS {
     my @roles = @_;
 
-    die '[ARGS] You must specify a least one role to compose methods in'
+    Carp::croak('[ARGS] You must specify a least one role to compose methods in')
         if scalar( @roles ) == 0;
 
     my (%methods, %conflicts, %required);
@@ -397,7 +398,7 @@ MOP::Internal::Util - For MOP Internal Use Only
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
