@@ -5,12 +5,13 @@ use strict;
 use warnings;
 
 use attributes ();
+use Carp       ();
 
 use UNIVERSAL::Object;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' };
@@ -33,10 +34,10 @@ sub BUILDARGS {
         %args = @_;
     }
 
-    die '[ARGS] You must specify a method body'
+    Carp::croak('[ARGS] You must specify a method body')
         unless $args{body};
 
-    die '[ARGS] The body specified must be a CODE reference'
+    Carp::croak('[ARGS] The body specified must be a CODE reference')
         unless ref $args{body} eq 'CODE';
 
     return \%args;
@@ -58,6 +59,11 @@ sub name {
     return MOP::Internal::Util::GET_GLOB_NAME( $self->body )
 }
 
+sub fully_qualified_name {
+    my ($self) = @_;
+    join '::' => $self->origin_stash, $self->name;
+}
+
 sub body {
     my ($self) = @_;
     return $$self;
@@ -86,7 +92,7 @@ sub origin_stash {
 sub was_aliased_from {
     my ($self, @classnames) = @_;
 
-    die '[ARGS] You must specify at least one classname'
+    Carp::croak('[ARGS] You must specify at least one classname')
         if scalar( @classnames ) == 0;
 
     my $class = $self->origin_stash;
@@ -118,7 +124,7 @@ MOP::Method - A representation of a method
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
