@@ -4,6 +4,8 @@ package MOP::Role;
 use strict;
 use warnings;
 
+use Carp ();
+
 use UNIVERSAL::Object;
 
 use MOP::Method;
@@ -11,7 +13,7 @@ use MOP::Slot;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' };
@@ -46,10 +48,10 @@ sub BUILDARGS {
         %args = @_;
     }
 
-    die '[ARGS] You must specify a package name'
+    Carp::croak('[ARGS] You must specify a package name')
         unless $args{name};
 
-    die '[ARGS] You must specify a valid package name, not `'.$_[0].'`'
+    Carp::croak('[ARGS] You must specify a valid package name, not `'.$_[0].'`')
         unless MOP::Internal::Util::IS_VALID_MODULE_NAME( $args{name} );
 
     return \%args;
@@ -115,7 +117,7 @@ sub roles {
 
 sub set_roles {
     my ($self, @roles) = @_;
-    die '[ARGS] You must specify at least one role'
+    Carp::croak('[ARGS] You must specify at least one role')
         if scalar( @roles ) == 0;
     MOP::Internal::Util::SET_GLOB_SLOT( $self->stash, 'DOES', \@roles );
     return;
@@ -124,7 +126,7 @@ sub set_roles {
 sub does_role {
     my ($self, $to_test) = @_;
 
-    die '[ARGS] You must specify a role'
+    Carp::croak('[ARGS] You must specify a role')
         unless $to_test;
 
     my @roles = $self->roles;
@@ -247,23 +249,26 @@ sub required_methods {
 #
 # - SL
 
-sub requires_method {
+sub has_required_method {
     my $stash = $_[0]->stash;
     my $name  = $_[1];
 
-    die '[ARGS] You must specify the name of the required method to look for'
+    Carp::croak('[ARGS] You must specify the name of the required method to look for')
         unless $name;
 
     return 0 unless exists $stash->{ $name };
     return MOP::Internal::Util::DOES_GLOB_HAVE_NULL_CV( $stash->{ $name } );
 }
 
+# consistency is a good thing ...
+sub requires_method { goto &has_required_method }
+
 sub get_required_method {
     my $class = $_[0]->name;
     my $stash = $_[0]->stash;
     my $name  = $_[1];
 
-    die '[ARGS] You must specify the name of the required method to get'
+    Carp::croak('[ARGS] You must specify the name of the required method to get')
         unless $name;
 
     # check these two easy cases first ...
@@ -284,7 +289,7 @@ sub get_required_method {
 sub add_required_method {
     my ($self, $name) = @_;
 
-    die '[ARGS] You must specify the name of the required method to add'
+    Carp::croak('[ARGS] You must specify the name of the required method to add')
         unless $name;
 
     # if we already have a glob there ...
@@ -293,7 +298,7 @@ sub add_required_method {
         return if MOP::Internal::Util::DOES_GLOB_HAVE_NULL_CV( $glob );
         # and if we don't and we have a CODE slot, we
         # need to die because this doesn't make sense
-        die "[CONFLICT] Cannot add a required method ($name) when there is a regular method already there"
+        Carp::croak("[CONFLICT] Cannot add a required method ($name) when there is a regular method already there")
             if defined *{ $glob }{CODE};
     }
 
@@ -307,7 +312,7 @@ sub add_required_method {
 sub delete_required_method {
     my ($self, $name) = @_;
 
-   die '[ARGS] You must specify the name of the required method to delete'
+   Carp::croak('[ARGS] You must specify the name of the required method to delete')
         unless $name;
 
     # check if we have a stash entry for $name ...
@@ -322,7 +327,7 @@ sub delete_required_method {
             # and if we have a CV slot, but it doesn't have
             # a NULL CV in it, then we need to die because
             # this doesn't make sense
-            die "[CONFLICT] Cannot delete a required method ($name) when there is a regular method already there"
+            Carp::croak("[CONFLICT] Cannot delete a required method ($name) when there is a regular method already there")
                 if defined *{ $glob }{CODE};
 
             # if we have the glob, but no CV slot (NULL or otherwise)
@@ -342,7 +347,7 @@ sub has_method {
     my $stash = $self->stash;
     my $name  = $_[1];
 
-    die '[ARGS] You must specify the name of the method to look for'
+    Carp::croak('[ARGS] You must specify the name of the method to look for')
         unless $name;
 
     # check these two easy cases first ...
@@ -370,7 +375,7 @@ sub get_method {
     my $stash = $self->stash;
     my $name  = $_[1];
 
-    die '[ARGS] You must specify the name of the method to get'
+    Carp::croak('[ARGS] You must specify the name of the method to get')
         unless $name;
 
     # check the easy cases first ...
@@ -395,10 +400,10 @@ sub get_method {
 sub add_method {
     my ($self, $name, $code) = @_;
 
-    die '[ARGS] You must specify the name of the method to add'
+    Carp::croak('[ARGS] You must specify the name of the method to add')
         unless $name;
 
-    die '[ARGS] You must specify a CODE reference to add as a method'
+    Carp::croak('[ARGS] You must specify a CODE reference to add as a method')
         unless $code && ref $code eq 'CODE';
 
     MOP::Internal::Util::INSTALL_CV( $self->name, $name, $code, set_subname => 1 );
@@ -408,7 +413,7 @@ sub add_method {
 sub delete_method {
     my ($self, $name) = @_;
 
-    die '[ARGS] You must specify the name of the method to delete'
+    Carp::croak('[ARGS] You must specify the name of the method to delete')
         unless $name;
 
     # check if we have a stash entry for $name ...
@@ -418,7 +423,7 @@ sub delete_method {
             # then we need to die because this
             # shouldn't happen, we should only
             # delete regular methods.
-            die "[CONFLICT] Cannot delete a regular method ($name) when there is a required method already there";
+            Carp::croak("[CONFLICT] Cannot delete a regular method ($name) when there is a required method already there");
         }
         else {
             # if we don't have a code slot ...
@@ -440,7 +445,7 @@ sub delete_method {
                 # trying to delete an alias using the
                 # regular method method
                 unless ( @roles && $method->was_aliased_from( @roles ) ) {
-                    die "[CONFLICT] Cannot delete a regular method ($name) when there is an aliased method already there"
+                    Carp::croak("[CONFLICT] Cannot delete a regular method ($name) when there is an aliased method already there")
                 }
             }
 
@@ -460,7 +465,7 @@ sub get_method_alias {
     my $stash = $_[0]->stash;
     my $name  = $_[1];
 
-    die '[ARGS] You must specify the name of the method alias to look for'
+    Carp::croak('[ARGS] You must specify the name of the method alias to look for')
         unless $name;
 
     # check the easy cases first ...
@@ -490,10 +495,10 @@ sub get_method_alias {
 sub alias_method {
     my ($self, $name, $code) = @_;
 
-    die '[ARGS] You must specify the name of the method alias to add'
+    Carp::croak('[ARGS] You must specify the name of the method alias to add')
         unless $name;
 
-    die '[ARGS] You must specify a CODE reference to add as a method alias'
+    Carp::croak('[ARGS] You must specify a CODE reference to add as a method alias')
         unless $code && ref $code eq 'CODE';
 
     MOP::Internal::Util::INSTALL_CV( $self->name, $name, $code, set_subname => 0 );
@@ -503,7 +508,7 @@ sub alias_method {
 sub delete_method_alias {
     my ($self, $name) = @_;
 
-    die '[ARGS] You must specify the name of the method alias to remove'
+    Carp::croak('[ARGS] You must specify the name of the method alias to remove')
         unless $name;
 
     # check if we have a stash entry for $name ...
@@ -513,7 +518,7 @@ sub delete_method_alias {
             # then we need to die because this
             # shouldn't happen, we should only
             # delete regular methods.
-            die "[CONFLICT] Cannot delete an aliased method ($name) when there is a required method already there";
+            Carp::croak("[CONFLICT] Cannot delete an aliased method ($name) when there is a required method already there");
         }
         else {
             # if we don't have a code slot ...
@@ -523,7 +528,7 @@ sub delete_method_alias {
             # otherwise, error accordingly
             my $method = MOP::Method->new( body => *{ $glob }{CODE} );
 
-            die "[CONFLICT] Cannot delete an aliased method ($name) when there is a regular method already there"
+            Carp::croak("[CONFLICT] Cannot delete an aliased method ($name) when there is a regular method already there")
                 if $method->origin_stash eq $self->name;
 
             # but if we have a regular method, then we
@@ -540,7 +545,7 @@ sub has_method_alias {
     my $stash = $_[0]->stash;
     my $name  = $_[1];
 
-    die '[ARGS] You must specify the name of the method alias to look for'
+    Carp::croak('[ARGS] You must specify the name of the method alias to look for')
         unless $name;
 
     # check these two easy cases first ...
@@ -605,7 +610,7 @@ sub has_slot {
     my $class = $self->name;
     my $has   = MOP::Internal::Util::GET_GLOB_SLOT( $self->stash, 'HAS', 'HASH' );
 
-    die '[ARGS] You must specify the name of the slot to look for'
+    Carp::croak('[ARGS] You must specify the name of the slot to look for')
         unless $name;
 
     return unless $has;
@@ -627,7 +632,7 @@ sub get_slot {
     my $class = $self->name;
     my $has   = MOP::Internal::Util::GET_GLOB_SLOT( $self->stash, 'HAS', 'HASH' );
 
-    die '[ARGS] You must specify the name of the slot to get'
+    Carp::croak('[ARGS] You must specify the name of the slot to get')
         unless $name;
 
     return unless $has;
@@ -651,17 +656,17 @@ sub add_slot {
     my $name        = $_[1];
     my $initializer = $_[2];
 
-    die '[ARGS] You must specify the name of the slot to add'
+    Carp::croak('[ARGS] You must specify the name of the slot to add')
         unless $name;
 
-    die '[ARGS] You must specify an initializer CODE reference to associate with the slot'
+    Carp::croak('[ARGS] You must specify an initializer CODE reference to associate with the slot')
         unless $initializer && ref $initializer eq 'CODE';
 
     my $stash = $self->stash;
     my $class = $self->name;
     my $slot  = MOP::Slot->new( name => $name, initializer => $initializer );
 
-    die '[ERROR] Slot is not from local (' . $class . '), it is from (' . $slot->origin_stash . ')'
+    Carp::croak('[ERROR] Slot is not from local (' . $class . '), it is from (' . $slot->origin_stash . ')')
         if $slot->origin_stash ne $class;
 
     my $has = MOP::Internal::Util::GET_GLOB_SLOT( $stash, 'HAS', 'HASH' );
@@ -678,7 +683,7 @@ sub delete_slot {
     my $stash = $self->stash;
     my $class = $self->name;
 
-    die '[ARGS] You must specify the name of the slot to delete'
+    Carp::croak('[ARGS] You must specify the name of the slot to delete')
         unless $name;
 
     my $has = MOP::Internal::Util::GET_GLOB_SLOT( $stash, 'HAS', 'HASH' );
@@ -686,7 +691,7 @@ sub delete_slot {
     return unless $has;
     return unless exists $has->{ $name };
 
-    die "[CONFLICT] Cannot delete a regular slot ($name) when there is an aliased slot already there"
+    Carp::croak("[CONFLICT] Cannot delete a regular slot ($name) when there is an aliased slot already there")
         if MOP::Slot->new(
             name        => $name,
             initializer => $has->{ $name }
@@ -703,7 +708,7 @@ sub has_slot_alias {
     my $class = $self->name;
     my $has   = MOP::Internal::Util::GET_GLOB_SLOT( $self->stash, 'HAS', 'HASH' );
 
-    die '[ARGS] You must specify the name of the slot alias to look for'
+    Carp::croak('[ARGS] You must specify the name of the slot alias to look for')
         unless $name;
 
     return unless $has;
@@ -721,7 +726,7 @@ sub get_slot_alias {
     my $class = $self->name;
     my $has   = MOP::Internal::Util::GET_GLOB_SLOT( $self->stash, 'HAS', 'HASH' );
 
-    die '[ARGS] You must specify the name of the slot alias to get'
+    Carp::croak('[ARGS] You must specify the name of the slot alias to get')
         unless $name;
 
     return unless $has;
@@ -743,17 +748,17 @@ sub alias_slot {
     my $name        = $_[1];
     my $initializer = $_[2];
 
-    die '[ARGS] You must specify the name of the slot alias to add'
+    Carp::croak('[ARGS] You must specify the name of the slot alias to add')
         unless $name;
 
-    die '[ARGS] You must specify an initializer CODE reference to associate with the slot alias'
+    Carp::croak('[ARGS] You must specify an initializer CODE reference to associate with the slot alias')
         unless $initializer && ref $initializer eq 'CODE';
 
     my $stash = $self->stash;
     my $class = $self->name;
     my $slot  = MOP::Slot->new( name => $name, initializer => $initializer );
 
-    die '[CONFLICT] Slot is from the local class (' . $class . '), it should be from a different class'
+    Carp::croak('[CONFLICT] Slot is from the local class (' . $class . '), it should be from a different class')
         if $slot->origin_stash eq $class;
 
     my $has = MOP::Internal::Util::GET_GLOB_SLOT( $stash, 'HAS', 'HASH' );
@@ -770,7 +775,7 @@ sub delete_slot_alias {
     my $stash = $self->stash;
     my $class = $self->name;
 
-    die '[ARGS] You must specify the name of the slot alias to delete'
+    Carp::croak('[ARGS] You must specify the name of the slot alias to delete')
         unless $name;
 
     my $has = MOP::Internal::Util::GET_GLOB_SLOT( $stash, 'HAS', 'HASH' );
@@ -778,7 +783,7 @@ sub delete_slot_alias {
     return unless $has;
     return unless exists $has->{ $name };
 
-    die "[CONFLICT] Cannot delete an slot alias ($name) when there is an regular slot already there"
+    Carp::croak("[CONFLICT] Cannot delete an slot alias ($name) when there is an regular slot already there")
         if MOP::Slot->new(
             name        => $name,
             initializer => $has->{ $name }
@@ -801,7 +806,7 @@ MOP::Role - A representation of a role
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
@@ -888,6 +893,8 @@ defintions, and I<may> consume other roles.
 
 =item C<requires_method( $name )>
 
+=item C<has_required_method( $name )>
+
 =item C<get_required_method( $name )>
 
 =item C<add_required_method( $name )>
