@@ -4,11 +4,13 @@ package MOP::Slot;
 use strict;
 use warnings;
 
+use Carp ();
+
 use UNIVERSAL::Object;
 
 use MOP::Internal::Util;
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 our @ISA; BEGIN { @ISA = 'UNIVERSAL::Object' }
@@ -28,11 +30,11 @@ sub BUILDARGS {
         $args = $class->SUPER::BUILDARGS( @_ );
     }
 
-    die '[ARGS] You must specify a slot name'
+    Carp::croak('[ARGS] You must specify a slot name')
         unless $args->{name};
-    die '[ARGS] You must specify a slot initializer'
+    Carp::croak('[ARGS] You must specify a slot initializer')
         unless $args->{initializer};
-    die '[ARGS] The initializer specified must be a CODE reference'
+    Carp::croak('[ARGS] The initializer specified must be a CODE reference')
         unless ref $args->{initializer} eq 'CODE';
 
     return $args;
@@ -75,7 +77,7 @@ sub origin_stash {
 sub was_aliased_from {
     my ($self, @classnames) = @_;
 
-    die '[ARGS] You must specify at least one classname'
+    Carp::croak('[ARGS] You must specify at least one classname')
         if scalar( @classnames ) == 0;
 
     my $class = $self->origin_stash;
@@ -97,7 +99,7 @@ MOP::Slot - A representation of a class slot
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
